Linode
-----

* Implement `linode.clone`
* Implement `linode.resize`
* Implement `linode.shutdown`
* Implement `linode.disk.delete`
* Implement `linode.disk.duplicate`
* Implement `linode.disk.resize`

Nodebalacer
-----

Implement all Nodebalancer functionality

DNS
-----

Implement all DNS functionality
